
//  this addrow has the same syntax as linalg[addrow] in Maple
//  It returns a copy of A which has been modified (A is left alone)
//  Note:  A is passed in by reference (note &) to save making a copy
//  but is made constant (note const) to avoid accidental modification.

#include <math.h>
#include "vecdefs.h"
#include "mvm.h"
MATRIX_double addrow(const MATRIX_double &A,int r1,int r2,double m)
{
  int c;
  int i;
  {
    MATRIX_double Acpy = A;
    c = A.dim(1);
    for(i = 1;i <= c;i++)
      Acpy(r2-1,i-1) += m*Acpy(r1-1,i-1);
     return(Acpy);
  }
}

//  Here is an addrow which modifies the original matrix A,
//  which is passed by reference (note the & and also the
//  void in front of addrowip)
//  I called it addrowip  (ip = inplace)


void addrowip(MATRIX_double &A,int r1,int r2,double m)
{
  int c;
  int i;
  {
    c = A.dim(1);
    for(i = 1;i <= c;i++)
      A(r2-1,i-1) += m*A(r1-1,i-1);
  }
}

// We can modify addrow(ip)  to get addcol(ip) 

MATRIX_double addcol(const MATRIX_double &A,int c1,int c2,double m)
{
  int r;
  int i;
  {
    MATRIX_double Acpy = A;
    r = A.dim(0);
    for(i = 1;i <= r;i++)
      Acpy(i-1,c2-1) += m*Acpy(i-1,c1-1);
    return(Acpy);
  }
}


// And then modify addcol to get addcolip

void addcolip(MATRIX_double &A,int c1,int c2,double m)
{
  int r;
  int i;
  {   
    r = A.dim(0);
    for(i = 1;i <= r;i++)
      A(i-1,c2-1) += m*A(i-1,c1-1); 
  }
}
